function [f,d] = func1d(x)
%
%  Input
%    x      argument of the function
%
%  Output
%    f      function value
%    d      derivative of the function
%

f = sin(x.^2)./x;

if nargout==2,
   d = 2 * cos(x.^2) - sin(x.^2) ./ x.^2;
end
